.. module:: enaml.widgets.dual_slider

=========================
enaml.widgets.dual_slider
=========================

.. rubric:: Classes

.. autosummary::
    :nosignatures:

    DualSlider


.. autoclass:: DualSlider
